Index: trunk/test/unit/org/openstreetmap/josm/command/conflict/ConflictAddCommandTest.java
===================================================================
--- trunk/test/unit/org/openstreetmap/josm/command/conflict/ConflictAddCommandTest.java	(revision 8916)
+++ trunk/test/unit/org/openstreetmap/josm/command/conflict/ConflictAddCommandTest.java	(revision 8917)
@@ -9,4 +9,5 @@
 import org.junit.Test;
 import org.openstreetmap.josm.JOSMFixture;
+import org.openstreetmap.josm.Main;
 import org.openstreetmap.josm.data.conflict.Conflict;
 import org.openstreetmap.josm.data.osm.DataSet;
@@ -24,5 +25,6 @@
     @BeforeClass
     public static void setUpBeforeClass() {
-        JOSMFixture.createUnitTestFixture().init();
+        JOSMFixture.createUnitTestFixture().init(true);
+        Main.map.mapView.addLayer(new OsmDataLayer(new DataSet(), null, null));
     }
 
@@ -32,5 +34,5 @@
     @Test
     public void testExecuteUndoCommand() {
-        OsmDataLayer layer = new OsmDataLayer(new DataSet(), null, null);
+        OsmDataLayer layer = Main.map.mapView.getEditLayer();
         Conflict<Node> conflict = new Conflict<>(new Node(), new Node());
         ConflictAddCommand cmd = new ConflictAddCommand(layer, conflict);
@@ -48,5 +50,5 @@
     @Test
     public void testGetDescriptionIcon() {
-        OsmDataLayer layer = new OsmDataLayer(new DataSet(), null, null);
+        OsmDataLayer layer = Main.map.mapView.getEditLayer();
         Conflict<Node> conflict = new Conflict<>(new Node(), new Node());
         assertNotNull(new ConflictAddCommand(layer, conflict).getDescriptionIcon());
Index: trunk/test/unit/org/openstreetmap/josm/command/conflict/CoordinateConflictResolveCommandTest.java
===================================================================
--- trunk/test/unit/org/openstreetmap/josm/command/conflict/CoordinateConflictResolveCommandTest.java	(revision 8916)
+++ trunk/test/unit/org/openstreetmap/josm/command/conflict/CoordinateConflictResolveCommandTest.java	(revision 8917)
@@ -2,4 +2,5 @@
 package org.openstreetmap.josm.command.conflict;
 
+import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
@@ -42,7 +43,7 @@
         CoordinateConflictResolveCommand cmd = new CoordinateConflictResolveCommand(conflict, MergeDecisionType.KEEP_MINE);
         assertTrue(cmd.executeCommand());
-        assertTrue(LatLon.ZERO.equals(conflict.getMy().getCoor()));
+        assertEquals(LatLon.ZERO, conflict.getMy().getCoor());
         cmd.undoCommand();
-        assertTrue(LatLon.ZERO.equals(conflict.getMy().getCoor()));
+        assertEquals(LatLon.ZERO, conflict.getMy().getCoor());
     }
 
@@ -55,7 +56,7 @@
         CoordinateConflictResolveCommand cmd = new CoordinateConflictResolveCommand(conflict, MergeDecisionType.KEEP_THEIR);
         assertTrue(cmd.executeCommand());
-        assertTrue(conflict.getTheir().getCoor().equals(conflict.getMy().getCoor()));
+        assertEquals(conflict.getTheir().getCoor(), conflict.getMy().getCoor());
         cmd.undoCommand();
         //assertTrue(LatLon.ZERO.equals(conflict.getMy().getCoor())); // FIXME it does not work
     }
 
@@ -55,7 +56,7 @@
         cmd.undoCommand();
-        //assertTrue(LatLon.ZERO.equals(conflict.getMy().getCoor())); // FIXME it does not work
+        //assertEquals(LatLon.ZERO, conflict.getMy().getCoor()); // FIXME it does not work
     }
 
